$.jqplot.BezierCurveRenderer.js

Renderer which draws lines as stacked bezier curves. Data for the line will not be specified as an array of [x, y] data point values, but as a an array of [start piont, bezier curve] So, the line is specified as: [[xstart, ystart], [cp1x, cp1y, cp2x, cp2y, xend, yend]].

Summary

$.jqplot.BezierCurveRenderer.js | Renderer which draws lines as stacked bezier curves.
Functions |
setGridData | converts the user data values to grid coordinates and stores them in the gridData array.
makeGridData | converts any arbitrary data values to grid coordinates and returns them.

### Functions

### setGridData

> $.jqplot.BezierCurveRenderer.prototype.setGridData = function( | plot | )

converts the user data values to grid coordinates and stores them in the gridData array. Called with scope of a series.

### makeGridData

> $.jqplot.BezierCurveRenderer.prototype.makeGridData = function( | data,
> | plot | )

converts any arbitrary data values to grid coordinates and returns them. This method exists so that plugins can use a series’ linerenderer to generate grid data points without overwriting the grid data associated with that series. Called with scope of a series.

> $.jqplot.BezierCurveRenderer.prototype.setGridData = function( | plot | )

converts the user data values to grid coordinates and stores them in the gridData array.

> $.jqplot.BezierCurveRenderer.prototype.makeGridData = function( | data,
> | plot | )

converts any arbitrary data values to grid coordinates and returns them.
Close